@@ -31,6 +31,7 @@ const STATEHUB_CLUSTER_TOKEN_SECRET_TYPE: &str = "statehub.io/cluster-token";
 const STATEHUB_CLUSTER_TOKEN_SECRET_NAME: &str = "statehub-cluster-token";
 const STATEHUB_CLUSTER_CONFIGMAP_NAME: &str = "statehub";
 
+#[derive(Debug)]
 pub(crate) struct Kubectl {
     kubeconfig: Kubeconfig,
     context: String,
@@ -59,6 +60,26 @@ impl Kubectl {
         })
     }
 
+    pub(crate) fn clone_for_context(&self, context: &str) -> Self {
+        let kubeconfig = self.kubeconfig.clone();
+        let context = context.to_string();
+        Self {
+            kubeconfig,
+            context,
+        }
+    }
+
+    pub(crate) fn has_context(&self, name: &str) -> bool {
+        self.kubeconfig
+            .contexts
+            .iter()
+            .any(|context| context.name == name)
+    }
+
+    pub(crate) fn _default_context(&self) -> Option<&str> {
+        None
+    }
+
     pub(crate) fn cluster_name(&self) -> v0::ClusterName {
         normalize_name(&self.context)
     }
@@ -233,6 +254,7 @@ impl Kubectl {
 
         self.all_nodes().await.map(group_nodes)
     }
+
     pub(crate) async fn collect_node_locations(&self) -> anyhow::Result<Vec<Location>> {
         self.get_regions(false)
             .await?
@@ -289,8 +311,7 @@ impl Kubectl {
     }
 }
 
-pub(crate) async fn validate_namespace(namespace: impl AsRef<str>) -> anyhow::Result<Namespace> {
-    let namespace = namespace.as_ref();
+pub(crate) async fn validate_namespace(namespace: &str) -> anyhow::Result<Namespace> {
     let kube = Kubectl::new().await?;
     let existing = kube
         .all_namespaces()
@@ -340,10 +361,6 @@ pub(crate) async fn store_cluster_token(namespace: &str, token: &str) -> anyhow:
         .await
 }
 
-pub(crate) fn helm_is_found() -> bool {
-    which::which("helm").is_ok()
-}
-
 pub(crate) fn extract_cluster_token(secret: &Secret) -> Option<Cow<'_, str>> {
     secret
         .data
