@@ -3,7 +3,8 @@
 // Use is subject to license terms.
 //
 
-use std::time::Duration;
+use std::env;
+use std::fs;
 
 use anyhow::Context;
 use indexmap::IndexMap;
@@ -124,7 +125,7 @@ impl StateHub {
     ) -> anyhow::Result<Output<v0::StateLocationAws>> {
         let aws = self.api.add_aws_location(name, region).await?;
         if wait {
-            let delay = Duration::from_secs(5);
+            let delay = time::Duration::from_secs(5);
             loop {
                 if self
                     .api
@@ -149,7 +150,7 @@ impl StateHub {
     ) -> anyhow::Result<Output<v0::StateLocationAzure>> {
         let azure = self.api.add_azure_location(name, region).await?;
         if wait {
-            let delay = Duration::from_secs(5);
+            let delay = time::Duration::from_secs(5);
             loop {
                 if self
                     .api
@@ -259,7 +260,7 @@ or run following commands before running 'statehub register-cluster`
                 );
             } else {
                 self.inform(format_args!(
-                    "Extdending state {} to {}",
+                    "Extending state {} to {}",
                     state.name, location
                 ))?;
                 self.add_location_helper(state, location, wait).await?;
@@ -287,7 +288,7 @@ or run following commands before running 'statehub register-cluster`
                 );
             } else {
                 self.inform(format_args!(
-                    "Extdending state {} to {}",
+                    "Extending state {} to {}",
                     state.name, location
                 ))?;
                 self.add_location_helper(&state, location, wait).await?;
@@ -371,7 +372,7 @@ or run following commands before running 'statehub register-cluster`
     ) -> anyhow::Result<Output<v0::Volume>> {
         let mut volume = self.api.delete_volume(state, volume).await?;
         if wait {
-            let delay = Duration::from_secs(5);
+            let delay = time::Duration::from_secs(5);
             loop {
                 match self.api.get_volume(state, &volume.name).await {
                     Ok(deleting) => volume = deleting,
@@ -437,7 +438,18 @@ or run following commands before running 'statehub register-cluster`
             .await
             .context(format!("Downloading version {}", version))?;
         log::debug!("Downloaded {} bytes", file.len());
-        Ok(())
+        self.replace_statehub_binary(file)
+            .ok_or_else(|| anyhow::anyhow!("Failed to replace the statehub binary"))
+    }
+
+    fn replace_statehub_binary(&self, contents: bytes::Bytes) -> Option<()> {
+        let statehub_exe = env::current_exe().ok()?;
+        let permissions = fs::metadata(&statehub_exe).ok()?.permissions();
+        let download = statehub_exe.parent()?.join(".statehub-download");
+        fs::write(&download, contents).ok()?;
+        fs::remove_file(&statehub_exe).ok()?;
+        fs::rename(&download, &statehub_exe).ok()?;
+        fs::set_permissions(statehub_exe, permissions).ok()
     }
 }
 
