@@ -100,6 +100,13 @@ enum Command {
 
     #[structopt(about = "Register new cluster", aliases = &["register-cl", "rc"], display_order(10))]
     RegisterCluster {
+        #[structopt(
+            help = "Non-interactive cluster registration, automatic defaults apply",
+            long,
+            visible_aliases = &["yes", "y"],
+        )]
+        non_interactive: bool,
+
         #[structopt(help = "Cluster name, defaults to current k8s context")]
         names: Vec<v0::ClusterName>,
 
@@ -414,6 +421,7 @@ impl Cli {
             Command::ListStates => statehub.list_states().await,
             Command::ShowState { name } => statehub.show_state(&name).await,
             Command::RegisterCluster {
+                non_interactive,
                 names,
                 states,
                 no_state,
@@ -425,6 +433,7 @@ impl Cli {
                 provider,
                 cleanup_grace,
             } => {
+                let interactive = !non_interactive;
                 let kubectl = k8s::Kubectl::new().await?;
                 for name in &names {
                     if !kubectl.has_context(name) {
@@ -459,7 +468,13 @@ impl Cli {
                     claim_unowned_states,
                     cleanup_grace,
                 );
-                if names.is_empty() {
+                if interactive {
+                    // Right now interactive_register_cluster() does very much the same job as
+                    // non-interactive counterpart. In the future we may handle it differently.
+                    statehub
+                        .interactive_register_cluster(names, kubectl, provider, register_cluster)
+                        .await
+                } else if names.is_empty() {
                     statehub
                         .register_single_cluster(kubectl, provider, register_cluster)
                         .await
@@ -658,6 +673,22 @@ impl StateHub {
             .print(&self.stdout, self.json)
     }
 
+    async fn interactive_register_cluster(
+        &self,
+        names: Vec<v0::ClusterName>,
+        kubectl: k8s::Kubectl,
+        provider: Option<v0::Provider>,
+        register_cluster: RegisterCluster,
+    ) -> anyhow::Result<()> {
+        if names.is_empty() {
+            self.register_single_cluster(kubectl, provider, register_cluster)
+                .await
+        } else {
+            self.register_multiple_clusters(names, kubectl, provider, register_cluster)
+                .await
+        }
+    }
+
     async fn register_single_cluster(
         &self,
         kubectl: k8s::Kubectl,
@@ -676,7 +707,6 @@ impl StateHub {
             .await
     }
 
-    #[allow(clippy::too_many_arguments)]
     async fn register_multiple_clusters(
         &self,
         names: Vec<v0::ClusterName>,
